@@ -46,7 +46,7 @@ class Domoticz(IPlugin):
 		idex= location + "_" + on_off
 		log.msg("index :  %s" % (idex))		
 		for rs in self.configuration_plugin['param_dz']:
-			log.msg("ids  :  %s" % (rs['ids']))
+#			log.msg("ids  :  %s" % (rs['ids']))
 			if rs['ids'] == idex :
 				bodies = rs['boy']
 				log.msg("BODIES  :  %s" % (bodies))
@@ -82,9 +82,9 @@ class Domoticz(IPlugin):
 		log.msg("index :  %s" % (idex))		
 #		log.msg("self.configuration_plugin['param_dz']:  %s" % (self.configuration_plugin['param_dz']))		
 		for rs in self.configuration_plugin['param_dz']:
-			log.msg("ids  :  %s" % (rs['ids']))
+#			log.msg("ids  :  %s" % (rs['ids']))
 			if rs['ids'] == idex :
-#				log.msg("index trouvé :  ***")
+				log.msg("index trouvé :  ***")
 				bodies = rs['boy']
 				log.msg("BODIES  :  %s" % (bodies))
 				log.msg("local  :  %s" % (local))
